"""HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.harmonic_analyses.reportable_property_results import (
    _5883,
)
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_HARMONIC_ANALYSIS_RESULTS_BROKEN_DOWN_BY_NODE_WITHIN_A_HARMONIC = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses.ReportablePropertyResults",
    "HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic",
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.harmonic_analyses.reportable_property_results import (
        _5895,
    )


__docformat__ = "restructuredtext en"
__all__ = ("HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic",)


Self = TypeVar("Self", bound="HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic")


class HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic(
    _5883.HarmonicAnalysisResultsBrokenDownByLocationWithinAHarmonic
):
    """HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic

    This is a mastapy class.
    """

    TYPE = _HARMONIC_ANALYSIS_RESULTS_BROKEN_DOWN_BY_NODE_WITHIN_A_HARMONIC
    _CastSelf = TypeVar(
        "_CastSelf",
        bound="_Cast_HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic",
    )

    class _Cast_HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic:
        """Special nested class for casting HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic to subclasses."""

        def __init__(
            self: "HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic._Cast_HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic",
            parent: "HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic",
        ):
            self._parent = parent

        @property
        def harmonic_analysis_results_broken_down_by_location_within_a_harmonic(
            self: "HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic._Cast_HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic",
        ) -> "_5883.HarmonicAnalysisResultsBrokenDownByLocationWithinAHarmonic":
            return self._parent._cast(
                _5883.HarmonicAnalysisResultsBrokenDownByLocationWithinAHarmonic
            )

        @property
        def harmonic_analysis_results_broken_down_by_node_within_a_harmonic(
            self: "HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic._Cast_HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic",
        ) -> "HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic":
            return self._parent

        def __getattr__(
            self: "HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic._Cast_HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self,
        instance_to_wrap: "HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic.TYPE",
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def node_name(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NodeName

        if temp is None:
            return ""

        return temp

    @property
    def acceleration(self: Self) -> "_5895.ResultsForResponseOfANodeOnAHarmonic":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.reportable_property_results.ResultsForResponseOfANodeOnAHarmonic

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Acceleration

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def displacement(self: Self) -> "_5895.ResultsForResponseOfANodeOnAHarmonic":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.reportable_property_results.ResultsForResponseOfANodeOnAHarmonic

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Displacement

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def force(self: Self) -> "_5895.ResultsForResponseOfANodeOnAHarmonic":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.reportable_property_results.ResultsForResponseOfANodeOnAHarmonic

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Force

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def velocity(self: Self) -> "_5895.ResultsForResponseOfANodeOnAHarmonic":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.reportable_property_results.ResultsForResponseOfANodeOnAHarmonic

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Velocity

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic._Cast_HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic":
        return self._Cast_HarmonicAnalysisResultsBrokenDownByNodeWithinAHarmonic(self)



"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._3525 import AbstractAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3526 import AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed
    from ._3527 import AbstractShaftSteadyStateSynchronousResponseAtASpeed
    from ._3528 import (
        AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3529 import AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3530 import AGMAGleasonConicalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3531 import AGMAGleasonConicalGearSteadyStateSynchronousResponseAtASpeed
    from ._3532 import AssemblySteadyStateSynchronousResponseAtASpeed
    from ._3533 import BearingSteadyStateSynchronousResponseAtASpeed
    from ._3534 import BeltConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3535 import BeltDriveSteadyStateSynchronousResponseAtASpeed
    from ._3536 import BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3537 import BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3538 import BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed
    from ._3539 import BevelDifferentialPlanetGearSteadyStateSynchronousResponseAtASpeed
    from ._3540 import BevelDifferentialSunGearSteadyStateSynchronousResponseAtASpeed
    from ._3541 import BevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3542 import BevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3543 import BevelGearSteadyStateSynchronousResponseAtASpeed
    from ._3544 import BoltedJointSteadyStateSynchronousResponseAtASpeed
    from ._3545 import BoltSteadyStateSynchronousResponseAtASpeed
    from ._3546 import ClutchConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3547 import ClutchHalfSteadyStateSynchronousResponseAtASpeed
    from ._3548 import ClutchSteadyStateSynchronousResponseAtASpeed
    from ._3549 import CoaxialConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3550 import ComponentSteadyStateSynchronousResponseAtASpeed
    from ._3551 import ConceptCouplingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3552 import ConceptCouplingHalfSteadyStateSynchronousResponseAtASpeed
    from ._3553 import ConceptCouplingSteadyStateSynchronousResponseAtASpeed
    from ._3554 import ConceptGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3555 import ConceptGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3556 import ConceptGearSteadyStateSynchronousResponseAtASpeed
    from ._3557 import ConicalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3558 import ConicalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3559 import ConicalGearSteadyStateSynchronousResponseAtASpeed
    from ._3560 import ConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3561 import ConnectorSteadyStateSynchronousResponseAtASpeed
    from ._3562 import CouplingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3563 import CouplingHalfSteadyStateSynchronousResponseAtASpeed
    from ._3564 import CouplingSteadyStateSynchronousResponseAtASpeed
    from ._3565 import CVTBeltConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3566 import CVTPulleySteadyStateSynchronousResponseAtASpeed
    from ._3567 import CVTSteadyStateSynchronousResponseAtASpeed
    from ._3568 import CycloidalAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3569 import (
        CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3570 import (
        CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3571 import CycloidalDiscSteadyStateSynchronousResponseAtASpeed
    from ._3572 import CylindricalGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3573 import CylindricalGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3574 import CylindricalGearSteadyStateSynchronousResponseAtASpeed
    from ._3575 import CylindricalPlanetGearSteadyStateSynchronousResponseAtASpeed
    from ._3576 import DatumSteadyStateSynchronousResponseAtASpeed
    from ._3577 import ExternalCADModelSteadyStateSynchronousResponseAtASpeed
    from ._3578 import FaceGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3579 import FaceGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3580 import FaceGearSteadyStateSynchronousResponseAtASpeed
    from ._3581 import FEPartSteadyStateSynchronousResponseAtASpeed
    from ._3582 import FlexiblePinAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3583 import GearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3584 import GearSetSteadyStateSynchronousResponseAtASpeed
    from ._3585 import GearSteadyStateSynchronousResponseAtASpeed
    from ._3586 import GuideDxfModelSteadyStateSynchronousResponseAtASpeed
    from ._3587 import HypoidGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3588 import HypoidGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3589 import HypoidGearSteadyStateSynchronousResponseAtASpeed
    from ._3590 import (
        InterMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3591 import (
        KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3592 import (
        KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3593 import (
        KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3594 import (
        KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3595 import (
        KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3596 import (
        KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3597 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3598 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3599 import (
        KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3600 import MassDiscSteadyStateSynchronousResponseAtASpeed
    from ._3601 import MeasurementComponentSteadyStateSynchronousResponseAtASpeed
    from ._3602 import MountableComponentSteadyStateSynchronousResponseAtASpeed
    from ._3603 import OilSealSteadyStateSynchronousResponseAtASpeed
    from ._3604 import PartSteadyStateSynchronousResponseAtASpeed
    from ._3605 import (
        PartToPartShearCouplingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3606 import PartToPartShearCouplingHalfSteadyStateSynchronousResponseAtASpeed
    from ._3607 import PartToPartShearCouplingSteadyStateSynchronousResponseAtASpeed
    from ._3608 import PlanetaryConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3609 import PlanetaryGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3610 import PlanetCarrierSteadyStateSynchronousResponseAtASpeed
    from ._3611 import PointLoadSteadyStateSynchronousResponseAtASpeed
    from ._3612 import PowerLoadSteadyStateSynchronousResponseAtASpeed
    from ._3613 import PulleySteadyStateSynchronousResponseAtASpeed
    from ._3614 import RingPinsSteadyStateSynchronousResponseAtASpeed
    from ._3615 import RingPinsToDiscConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3616 import RollingRingAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3617 import RollingRingConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3618 import RollingRingSteadyStateSynchronousResponseAtASpeed
    from ._3619 import RootAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3620 import ShaftHubConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3621 import ShaftSteadyStateSynchronousResponseAtASpeed
    from ._3622 import (
        ShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from ._3623 import SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed
    from ._3624 import SpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3625 import SpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3626 import SpiralBevelGearSteadyStateSynchronousResponseAtASpeed
    from ._3627 import SpringDamperConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3628 import SpringDamperHalfSteadyStateSynchronousResponseAtASpeed
    from ._3629 import SpringDamperSteadyStateSynchronousResponseAtASpeed
    from ._3630 import SteadyStateSynchronousResponseAtASpeed
    from ._3631 import StraightBevelDiffGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3632 import StraightBevelDiffGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3633 import StraightBevelDiffGearSteadyStateSynchronousResponseAtASpeed
    from ._3634 import StraightBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3635 import StraightBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3636 import StraightBevelGearSteadyStateSynchronousResponseAtASpeed
    from ._3637 import StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed
    from ._3638 import StraightBevelSunGearSteadyStateSynchronousResponseAtASpeed
    from ._3639 import SynchroniserHalfSteadyStateSynchronousResponseAtASpeed
    from ._3640 import SynchroniserPartSteadyStateSynchronousResponseAtASpeed
    from ._3641 import SynchroniserSleeveSteadyStateSynchronousResponseAtASpeed
    from ._3642 import SynchroniserSteadyStateSynchronousResponseAtASpeed
    from ._3643 import TorqueConverterConnectionSteadyStateSynchronousResponseAtASpeed
    from ._3644 import TorqueConverterPumpSteadyStateSynchronousResponseAtASpeed
    from ._3645 import TorqueConverterSteadyStateSynchronousResponseAtASpeed
    from ._3646 import TorqueConverterTurbineSteadyStateSynchronousResponseAtASpeed
    from ._3647 import UnbalancedMassSteadyStateSynchronousResponseAtASpeed
    from ._3648 import VirtualComponentSteadyStateSynchronousResponseAtASpeed
    from ._3649 import WormGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3650 import WormGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3651 import WormGearSteadyStateSynchronousResponseAtASpeed
    from ._3652 import ZerolBevelGearMeshSteadyStateSynchronousResponseAtASpeed
    from ._3653 import ZerolBevelGearSetSteadyStateSynchronousResponseAtASpeed
    from ._3654 import ZerolBevelGearSteadyStateSynchronousResponseAtASpeed
else:
    import_structure = {
        "_3525": ["AbstractAssemblySteadyStateSynchronousResponseAtASpeed"],
        "_3526": ["AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed"],
        "_3527": ["AbstractShaftSteadyStateSynchronousResponseAtASpeed"],
        "_3528": [
            "AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3529": ["AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3530": ["AGMAGleasonConicalGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3531": ["AGMAGleasonConicalGearSteadyStateSynchronousResponseAtASpeed"],
        "_3532": ["AssemblySteadyStateSynchronousResponseAtASpeed"],
        "_3533": ["BearingSteadyStateSynchronousResponseAtASpeed"],
        "_3534": ["BeltConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3535": ["BeltDriveSteadyStateSynchronousResponseAtASpeed"],
        "_3536": ["BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3537": ["BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3538": ["BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed"],
        "_3539": ["BevelDifferentialPlanetGearSteadyStateSynchronousResponseAtASpeed"],
        "_3540": ["BevelDifferentialSunGearSteadyStateSynchronousResponseAtASpeed"],
        "_3541": ["BevelGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3542": ["BevelGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3543": ["BevelGearSteadyStateSynchronousResponseAtASpeed"],
        "_3544": ["BoltedJointSteadyStateSynchronousResponseAtASpeed"],
        "_3545": ["BoltSteadyStateSynchronousResponseAtASpeed"],
        "_3546": ["ClutchConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3547": ["ClutchHalfSteadyStateSynchronousResponseAtASpeed"],
        "_3548": ["ClutchSteadyStateSynchronousResponseAtASpeed"],
        "_3549": ["CoaxialConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3550": ["ComponentSteadyStateSynchronousResponseAtASpeed"],
        "_3551": ["ConceptCouplingConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3552": ["ConceptCouplingHalfSteadyStateSynchronousResponseAtASpeed"],
        "_3553": ["ConceptCouplingSteadyStateSynchronousResponseAtASpeed"],
        "_3554": ["ConceptGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3555": ["ConceptGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3556": ["ConceptGearSteadyStateSynchronousResponseAtASpeed"],
        "_3557": ["ConicalGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3558": ["ConicalGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3559": ["ConicalGearSteadyStateSynchronousResponseAtASpeed"],
        "_3560": ["ConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3561": ["ConnectorSteadyStateSynchronousResponseAtASpeed"],
        "_3562": ["CouplingConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3563": ["CouplingHalfSteadyStateSynchronousResponseAtASpeed"],
        "_3564": ["CouplingSteadyStateSynchronousResponseAtASpeed"],
        "_3565": ["CVTBeltConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3566": ["CVTPulleySteadyStateSynchronousResponseAtASpeed"],
        "_3567": ["CVTSteadyStateSynchronousResponseAtASpeed"],
        "_3568": ["CycloidalAssemblySteadyStateSynchronousResponseAtASpeed"],
        "_3569": [
            "CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3570": [
            "CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3571": ["CycloidalDiscSteadyStateSynchronousResponseAtASpeed"],
        "_3572": ["CylindricalGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3573": ["CylindricalGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3574": ["CylindricalGearSteadyStateSynchronousResponseAtASpeed"],
        "_3575": ["CylindricalPlanetGearSteadyStateSynchronousResponseAtASpeed"],
        "_3576": ["DatumSteadyStateSynchronousResponseAtASpeed"],
        "_3577": ["ExternalCADModelSteadyStateSynchronousResponseAtASpeed"],
        "_3578": ["FaceGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3579": ["FaceGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3580": ["FaceGearSteadyStateSynchronousResponseAtASpeed"],
        "_3581": ["FEPartSteadyStateSynchronousResponseAtASpeed"],
        "_3582": ["FlexiblePinAssemblySteadyStateSynchronousResponseAtASpeed"],
        "_3583": ["GearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3584": ["GearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3585": ["GearSteadyStateSynchronousResponseAtASpeed"],
        "_3586": ["GuideDxfModelSteadyStateSynchronousResponseAtASpeed"],
        "_3587": ["HypoidGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3588": ["HypoidGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3589": ["HypoidGearSteadyStateSynchronousResponseAtASpeed"],
        "_3590": [
            "InterMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3591": [
            "KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3592": [
            "KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3593": [
            "KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3594": [
            "KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3595": [
            "KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3596": [
            "KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3597": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3598": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3599": [
            "KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3600": ["MassDiscSteadyStateSynchronousResponseAtASpeed"],
        "_3601": ["MeasurementComponentSteadyStateSynchronousResponseAtASpeed"],
        "_3602": ["MountableComponentSteadyStateSynchronousResponseAtASpeed"],
        "_3603": ["OilSealSteadyStateSynchronousResponseAtASpeed"],
        "_3604": ["PartSteadyStateSynchronousResponseAtASpeed"],
        "_3605": [
            "PartToPartShearCouplingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3606": ["PartToPartShearCouplingHalfSteadyStateSynchronousResponseAtASpeed"],
        "_3607": ["PartToPartShearCouplingSteadyStateSynchronousResponseAtASpeed"],
        "_3608": ["PlanetaryConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3609": ["PlanetaryGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3610": ["PlanetCarrierSteadyStateSynchronousResponseAtASpeed"],
        "_3611": ["PointLoadSteadyStateSynchronousResponseAtASpeed"],
        "_3612": ["PowerLoadSteadyStateSynchronousResponseAtASpeed"],
        "_3613": ["PulleySteadyStateSynchronousResponseAtASpeed"],
        "_3614": ["RingPinsSteadyStateSynchronousResponseAtASpeed"],
        "_3615": ["RingPinsToDiscConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3616": ["RollingRingAssemblySteadyStateSynchronousResponseAtASpeed"],
        "_3617": ["RollingRingConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3618": ["RollingRingSteadyStateSynchronousResponseAtASpeed"],
        "_3619": ["RootAssemblySteadyStateSynchronousResponseAtASpeed"],
        "_3620": ["ShaftHubConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3621": ["ShaftSteadyStateSynchronousResponseAtASpeed"],
        "_3622": [
            "ShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_3623": ["SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed"],
        "_3624": ["SpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3625": ["SpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3626": ["SpiralBevelGearSteadyStateSynchronousResponseAtASpeed"],
        "_3627": ["SpringDamperConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3628": ["SpringDamperHalfSteadyStateSynchronousResponseAtASpeed"],
        "_3629": ["SpringDamperSteadyStateSynchronousResponseAtASpeed"],
        "_3630": ["SteadyStateSynchronousResponseAtASpeed"],
        "_3631": ["StraightBevelDiffGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3632": ["StraightBevelDiffGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3633": ["StraightBevelDiffGearSteadyStateSynchronousResponseAtASpeed"],
        "_3634": ["StraightBevelGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3635": ["StraightBevelGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3636": ["StraightBevelGearSteadyStateSynchronousResponseAtASpeed"],
        "_3637": ["StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed"],
        "_3638": ["StraightBevelSunGearSteadyStateSynchronousResponseAtASpeed"],
        "_3639": ["SynchroniserHalfSteadyStateSynchronousResponseAtASpeed"],
        "_3640": ["SynchroniserPartSteadyStateSynchronousResponseAtASpeed"],
        "_3641": ["SynchroniserSleeveSteadyStateSynchronousResponseAtASpeed"],
        "_3642": ["SynchroniserSteadyStateSynchronousResponseAtASpeed"],
        "_3643": ["TorqueConverterConnectionSteadyStateSynchronousResponseAtASpeed"],
        "_3644": ["TorqueConverterPumpSteadyStateSynchronousResponseAtASpeed"],
        "_3645": ["TorqueConverterSteadyStateSynchronousResponseAtASpeed"],
        "_3646": ["TorqueConverterTurbineSteadyStateSynchronousResponseAtASpeed"],
        "_3647": ["UnbalancedMassSteadyStateSynchronousResponseAtASpeed"],
        "_3648": ["VirtualComponentSteadyStateSynchronousResponseAtASpeed"],
        "_3649": ["WormGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3650": ["WormGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3651": ["WormGearSteadyStateSynchronousResponseAtASpeed"],
        "_3652": ["ZerolBevelGearMeshSteadyStateSynchronousResponseAtASpeed"],
        "_3653": ["ZerolBevelGearSetSteadyStateSynchronousResponseAtASpeed"],
        "_3654": ["ZerolBevelGearSteadyStateSynchronousResponseAtASpeed"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "AbstractAssemblySteadyStateSynchronousResponseAtASpeed",
    "AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed",
    "AbstractShaftSteadyStateSynchronousResponseAtASpeed",
    "AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed",
    "AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseAtASpeed",
    "AGMAGleasonConicalGearSetSteadyStateSynchronousResponseAtASpeed",
    "AGMAGleasonConicalGearSteadyStateSynchronousResponseAtASpeed",
    "AssemblySteadyStateSynchronousResponseAtASpeed",
    "BearingSteadyStateSynchronousResponseAtASpeed",
    "BeltConnectionSteadyStateSynchronousResponseAtASpeed",
    "BeltDriveSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialPlanetGearSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialSunGearSteadyStateSynchronousResponseAtASpeed",
    "BevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "BevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "BevelGearSteadyStateSynchronousResponseAtASpeed",
    "BoltedJointSteadyStateSynchronousResponseAtASpeed",
    "BoltSteadyStateSynchronousResponseAtASpeed",
    "ClutchConnectionSteadyStateSynchronousResponseAtASpeed",
    "ClutchHalfSteadyStateSynchronousResponseAtASpeed",
    "ClutchSteadyStateSynchronousResponseAtASpeed",
    "CoaxialConnectionSteadyStateSynchronousResponseAtASpeed",
    "ComponentSteadyStateSynchronousResponseAtASpeed",
    "ConceptCouplingConnectionSteadyStateSynchronousResponseAtASpeed",
    "ConceptCouplingHalfSteadyStateSynchronousResponseAtASpeed",
    "ConceptCouplingSteadyStateSynchronousResponseAtASpeed",
    "ConceptGearMeshSteadyStateSynchronousResponseAtASpeed",
    "ConceptGearSetSteadyStateSynchronousResponseAtASpeed",
    "ConceptGearSteadyStateSynchronousResponseAtASpeed",
    "ConicalGearMeshSteadyStateSynchronousResponseAtASpeed",
    "ConicalGearSetSteadyStateSynchronousResponseAtASpeed",
    "ConicalGearSteadyStateSynchronousResponseAtASpeed",
    "ConnectionSteadyStateSynchronousResponseAtASpeed",
    "ConnectorSteadyStateSynchronousResponseAtASpeed",
    "CouplingConnectionSteadyStateSynchronousResponseAtASpeed",
    "CouplingHalfSteadyStateSynchronousResponseAtASpeed",
    "CouplingSteadyStateSynchronousResponseAtASpeed",
    "CVTBeltConnectionSteadyStateSynchronousResponseAtASpeed",
    "CVTPulleySteadyStateSynchronousResponseAtASpeed",
    "CVTSteadyStateSynchronousResponseAtASpeed",
    "CycloidalAssemblySteadyStateSynchronousResponseAtASpeed",
    "CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseAtASpeed",
    "CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseAtASpeed",
    "CycloidalDiscSteadyStateSynchronousResponseAtASpeed",
    "CylindricalGearMeshSteadyStateSynchronousResponseAtASpeed",
    "CylindricalGearSetSteadyStateSynchronousResponseAtASpeed",
    "CylindricalGearSteadyStateSynchronousResponseAtASpeed",
    "CylindricalPlanetGearSteadyStateSynchronousResponseAtASpeed",
    "DatumSteadyStateSynchronousResponseAtASpeed",
    "ExternalCADModelSteadyStateSynchronousResponseAtASpeed",
    "FaceGearMeshSteadyStateSynchronousResponseAtASpeed",
    "FaceGearSetSteadyStateSynchronousResponseAtASpeed",
    "FaceGearSteadyStateSynchronousResponseAtASpeed",
    "FEPartSteadyStateSynchronousResponseAtASpeed",
    "FlexiblePinAssemblySteadyStateSynchronousResponseAtASpeed",
    "GearMeshSteadyStateSynchronousResponseAtASpeed",
    "GearSetSteadyStateSynchronousResponseAtASpeed",
    "GearSteadyStateSynchronousResponseAtASpeed",
    "GuideDxfModelSteadyStateSynchronousResponseAtASpeed",
    "HypoidGearMeshSteadyStateSynchronousResponseAtASpeed",
    "HypoidGearSetSteadyStateSynchronousResponseAtASpeed",
    "HypoidGearSteadyStateSynchronousResponseAtASpeed",
    "InterMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseAtASpeed",
    "MassDiscSteadyStateSynchronousResponseAtASpeed",
    "MeasurementComponentSteadyStateSynchronousResponseAtASpeed",
    "MountableComponentSteadyStateSynchronousResponseAtASpeed",
    "OilSealSteadyStateSynchronousResponseAtASpeed",
    "PartSteadyStateSynchronousResponseAtASpeed",
    "PartToPartShearCouplingConnectionSteadyStateSynchronousResponseAtASpeed",
    "PartToPartShearCouplingHalfSteadyStateSynchronousResponseAtASpeed",
    "PartToPartShearCouplingSteadyStateSynchronousResponseAtASpeed",
    "PlanetaryConnectionSteadyStateSynchronousResponseAtASpeed",
    "PlanetaryGearSetSteadyStateSynchronousResponseAtASpeed",
    "PlanetCarrierSteadyStateSynchronousResponseAtASpeed",
    "PointLoadSteadyStateSynchronousResponseAtASpeed",
    "PowerLoadSteadyStateSynchronousResponseAtASpeed",
    "PulleySteadyStateSynchronousResponseAtASpeed",
    "RingPinsSteadyStateSynchronousResponseAtASpeed",
    "RingPinsToDiscConnectionSteadyStateSynchronousResponseAtASpeed",
    "RollingRingAssemblySteadyStateSynchronousResponseAtASpeed",
    "RollingRingConnectionSteadyStateSynchronousResponseAtASpeed",
    "RollingRingSteadyStateSynchronousResponseAtASpeed",
    "RootAssemblySteadyStateSynchronousResponseAtASpeed",
    "ShaftHubConnectionSteadyStateSynchronousResponseAtASpeed",
    "ShaftSteadyStateSynchronousResponseAtASpeed",
    "ShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed",
    "SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed",
    "SpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "SpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "SpiralBevelGearSteadyStateSynchronousResponseAtASpeed",
    "SpringDamperConnectionSteadyStateSynchronousResponseAtASpeed",
    "SpringDamperHalfSteadyStateSynchronousResponseAtASpeed",
    "SpringDamperSteadyStateSynchronousResponseAtASpeed",
    "SteadyStateSynchronousResponseAtASpeed",
    "StraightBevelDiffGearMeshSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelDiffGearSetSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelDiffGearSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelGearSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelSunGearSteadyStateSynchronousResponseAtASpeed",
    "SynchroniserHalfSteadyStateSynchronousResponseAtASpeed",
    "SynchroniserPartSteadyStateSynchronousResponseAtASpeed",
    "SynchroniserSleeveSteadyStateSynchronousResponseAtASpeed",
    "SynchroniserSteadyStateSynchronousResponseAtASpeed",
    "TorqueConverterConnectionSteadyStateSynchronousResponseAtASpeed",
    "TorqueConverterPumpSteadyStateSynchronousResponseAtASpeed",
    "TorqueConverterSteadyStateSynchronousResponseAtASpeed",
    "TorqueConverterTurbineSteadyStateSynchronousResponseAtASpeed",
    "UnbalancedMassSteadyStateSynchronousResponseAtASpeed",
    "VirtualComponentSteadyStateSynchronousResponseAtASpeed",
    "WormGearMeshSteadyStateSynchronousResponseAtASpeed",
    "WormGearSetSteadyStateSynchronousResponseAtASpeed",
    "WormGearSteadyStateSynchronousResponseAtASpeed",
    "ZerolBevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "ZerolBevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "ZerolBevelGearSteadyStateSynchronousResponseAtASpeed",
)



"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._5397 import AbstractAssemblyMultibodyDynamicsAnalysis
    from ._5398 import AbstractShaftMultibodyDynamicsAnalysis
    from ._5399 import AbstractShaftOrHousingMultibodyDynamicsAnalysis
    from ._5400 import (
        AbstractShaftToMountableComponentConnectionMultibodyDynamicsAnalysis,
    )
    from ._5401 import AGMAGleasonConicalGearMeshMultibodyDynamicsAnalysis
    from ._5402 import AGMAGleasonConicalGearMultibodyDynamicsAnalysis
    from ._5403 import AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis
    from ._5404 import AnalysisTypes
    from ._5405 import AssemblyMultibodyDynamicsAnalysis
    from ._5406 import BearingMultibodyDynamicsAnalysis
    from ._5407 import BearingStiffnessModel
    from ._5408 import BeltConnectionMultibodyDynamicsAnalysis
    from ._5409 import BeltDriveMultibodyDynamicsAnalysis
    from ._5410 import BevelDifferentialGearMeshMultibodyDynamicsAnalysis
    from ._5411 import BevelDifferentialGearMultibodyDynamicsAnalysis
    from ._5412 import BevelDifferentialGearSetMultibodyDynamicsAnalysis
    from ._5413 import BevelDifferentialPlanetGearMultibodyDynamicsAnalysis
    from ._5414 import BevelDifferentialSunGearMultibodyDynamicsAnalysis
    from ._5415 import BevelGearMeshMultibodyDynamicsAnalysis
    from ._5416 import BevelGearMultibodyDynamicsAnalysis
    from ._5417 import BevelGearSetMultibodyDynamicsAnalysis
    from ._5418 import BoltedJointMultibodyDynamicsAnalysis
    from ._5419 import BoltMultibodyDynamicsAnalysis
    from ._5420 import ClutchConnectionMultibodyDynamicsAnalysis
    from ._5421 import ClutchHalfMultibodyDynamicsAnalysis
    from ._5422 import ClutchMultibodyDynamicsAnalysis
    from ._5423 import ClutchSpringType
    from ._5424 import CoaxialConnectionMultibodyDynamicsAnalysis
    from ._5425 import ComponentMultibodyDynamicsAnalysis
    from ._5426 import ConceptCouplingConnectionMultibodyDynamicsAnalysis
    from ._5427 import ConceptCouplingHalfMultibodyDynamicsAnalysis
    from ._5428 import ConceptCouplingMultibodyDynamicsAnalysis
    from ._5429 import ConceptGearMeshMultibodyDynamicsAnalysis
    from ._5430 import ConceptGearMultibodyDynamicsAnalysis
    from ._5431 import ConceptGearSetMultibodyDynamicsAnalysis
    from ._5432 import ConicalGearMeshMultibodyDynamicsAnalysis
    from ._5433 import ConicalGearMultibodyDynamicsAnalysis
    from ._5434 import ConicalGearSetMultibodyDynamicsAnalysis
    from ._5435 import ConnectionMultibodyDynamicsAnalysis
    from ._5436 import ConnectorMultibodyDynamicsAnalysis
    from ._5437 import CouplingConnectionMultibodyDynamicsAnalysis
    from ._5438 import CouplingHalfMultibodyDynamicsAnalysis
    from ._5439 import CouplingMultibodyDynamicsAnalysis
    from ._5440 import CVTBeltConnectionMultibodyDynamicsAnalysis
    from ._5441 import CVTMultibodyDynamicsAnalysis
    from ._5442 import CVTPulleyMultibodyDynamicsAnalysis
    from ._5443 import CycloidalAssemblyMultibodyDynamicsAnalysis
    from ._5444 import CycloidalDiscCentralBearingConnectionMultibodyDynamicsAnalysis
    from ._5445 import CycloidalDiscMultibodyDynamicsAnalysis
    from ._5446 import CycloidalDiscPlanetaryBearingConnectionMultibodyDynamicsAnalysis
    from ._5447 import CylindricalGearMeshMultibodyDynamicsAnalysis
    from ._5448 import CylindricalGearMultibodyDynamicsAnalysis
    from ._5449 import CylindricalGearSetMultibodyDynamicsAnalysis
    from ._5450 import CylindricalPlanetGearMultibodyDynamicsAnalysis
    from ._5451 import DatumMultibodyDynamicsAnalysis
    from ._5452 import ExternalCADModelMultibodyDynamicsAnalysis
    from ._5453 import FaceGearMeshMultibodyDynamicsAnalysis
    from ._5454 import FaceGearMultibodyDynamicsAnalysis
    from ._5455 import FaceGearSetMultibodyDynamicsAnalysis
    from ._5456 import FEPartMultibodyDynamicsAnalysis
    from ._5457 import FlexiblePinAssemblyMultibodyDynamicsAnalysis
    from ._5458 import GearMeshMultibodyDynamicsAnalysis
    from ._5459 import GearMeshStiffnessModel
    from ._5460 import GearMultibodyDynamicsAnalysis
    from ._5461 import GearSetMultibodyDynamicsAnalysis
    from ._5462 import GuideDxfModelMultibodyDynamicsAnalysis
    from ._5463 import HypoidGearMeshMultibodyDynamicsAnalysis
    from ._5464 import HypoidGearMultibodyDynamicsAnalysis
    from ._5465 import HypoidGearSetMultibodyDynamicsAnalysis
    from ._5466 import InertiaAdjustedLoadCasePeriodMethod
    from ._5467 import InertiaAdjustedLoadCaseResultsToCreate
    from ._5468 import InputSignalFilterLevel
    from ._5469 import InputVelocityForRunUpProcessingType
    from ._5470 import InterMountableComponentConnectionMultibodyDynamicsAnalysis
    from ._5471 import KlingelnbergCycloPalloidConicalGearMeshMultibodyDynamicsAnalysis
    from ._5472 import KlingelnbergCycloPalloidConicalGearMultibodyDynamicsAnalysis
    from ._5473 import KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis
    from ._5474 import KlingelnbergCycloPalloidHypoidGearMeshMultibodyDynamicsAnalysis
    from ._5475 import KlingelnbergCycloPalloidHypoidGearMultibodyDynamicsAnalysis
    from ._5476 import KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis
    from ._5477 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshMultibodyDynamicsAnalysis,
    )
    from ._5478 import KlingelnbergCycloPalloidSpiralBevelGearMultibodyDynamicsAnalysis
    from ._5479 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis,
    )
    from ._5480 import MassDiscMultibodyDynamicsAnalysis
    from ._5481 import MBDAnalysisDrawStyle
    from ._5482 import MBDAnalysisOptions
    from ._5483 import MBDRunUpAnalysisOptions
    from ._5484 import MeasurementComponentMultibodyDynamicsAnalysis
    from ._5485 import MountableComponentMultibodyDynamicsAnalysis
    from ._5486 import MultibodyDynamicsAnalysis
    from ._5487 import OilSealMultibodyDynamicsAnalysis
    from ._5488 import PartMultibodyDynamicsAnalysis
    from ._5489 import PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis
    from ._5490 import PartToPartShearCouplingHalfMultibodyDynamicsAnalysis
    from ._5491 import PartToPartShearCouplingMultibodyDynamicsAnalysis
    from ._5492 import PlanetaryConnectionMultibodyDynamicsAnalysis
    from ._5493 import PlanetaryGearSetMultibodyDynamicsAnalysis
    from ._5494 import PlanetCarrierMultibodyDynamicsAnalysis
    from ._5495 import PointLoadMultibodyDynamicsAnalysis
    from ._5496 import PowerLoadMultibodyDynamicsAnalysis
    from ._5497 import PulleyMultibodyDynamicsAnalysis
    from ._5498 import RingPinsMultibodyDynamicsAnalysis
    from ._5499 import RingPinsToDiscConnectionMultibodyDynamicsAnalysis
    from ._5500 import RollingRingAssemblyMultibodyDynamicsAnalysis
    from ._5501 import RollingRingConnectionMultibodyDynamicsAnalysis
    from ._5502 import RollingRingMultibodyDynamicsAnalysis
    from ._5503 import RootAssemblyMultibodyDynamicsAnalysis
    from ._5504 import RunUpDrivingMode
    from ._5505 import ShaftAndHousingFlexibilityOption
    from ._5506 import ShaftHubConnectionMultibodyDynamicsAnalysis
    from ._5507 import ShaftMultibodyDynamicsAnalysis
    from ._5508 import ShaftToMountableComponentConnectionMultibodyDynamicsAnalysis
    from ._5509 import ShapeOfInitialAccelerationPeriodForRunUp
    from ._5510 import SpecialisedAssemblyMultibodyDynamicsAnalysis
    from ._5511 import SpiralBevelGearMeshMultibodyDynamicsAnalysis
    from ._5512 import SpiralBevelGearMultibodyDynamicsAnalysis
    from ._5513 import SpiralBevelGearSetMultibodyDynamicsAnalysis
    from ._5514 import SpringDamperConnectionMultibodyDynamicsAnalysis
    from ._5515 import SpringDamperHalfMultibodyDynamicsAnalysis
    from ._5516 import SpringDamperMultibodyDynamicsAnalysis
    from ._5517 import StraightBevelDiffGearMeshMultibodyDynamicsAnalysis
    from ._5518 import StraightBevelDiffGearMultibodyDynamicsAnalysis
    from ._5519 import StraightBevelDiffGearSetMultibodyDynamicsAnalysis
    from ._5520 import StraightBevelGearMeshMultibodyDynamicsAnalysis
    from ._5521 import StraightBevelGearMultibodyDynamicsAnalysis
    from ._5522 import StraightBevelGearSetMultibodyDynamicsAnalysis
    from ._5523 import StraightBevelPlanetGearMultibodyDynamicsAnalysis
    from ._5524 import StraightBevelSunGearMultibodyDynamicsAnalysis
    from ._5525 import SynchroniserHalfMultibodyDynamicsAnalysis
    from ._5526 import SynchroniserMultibodyDynamicsAnalysis
    from ._5527 import SynchroniserPartMultibodyDynamicsAnalysis
    from ._5528 import SynchroniserSleeveMultibodyDynamicsAnalysis
    from ._5529 import TorqueConverterConnectionMultibodyDynamicsAnalysis
    from ._5530 import TorqueConverterLockupRule
    from ._5531 import TorqueConverterMultibodyDynamicsAnalysis
    from ._5532 import TorqueConverterPumpMultibodyDynamicsAnalysis
    from ._5533 import TorqueConverterStatus
    from ._5534 import TorqueConverterTurbineMultibodyDynamicsAnalysis
    from ._5535 import UnbalancedMassMultibodyDynamicsAnalysis
    from ._5536 import VirtualComponentMultibodyDynamicsAnalysis
    from ._5537 import WheelSlipType
    from ._5538 import WormGearMeshMultibodyDynamicsAnalysis
    from ._5539 import WormGearMultibodyDynamicsAnalysis
    from ._5540 import WormGearSetMultibodyDynamicsAnalysis
    from ._5541 import ZerolBevelGearMeshMultibodyDynamicsAnalysis
    from ._5542 import ZerolBevelGearMultibodyDynamicsAnalysis
    from ._5543 import ZerolBevelGearSetMultibodyDynamicsAnalysis
else:
    import_structure = {
        "_5397": ["AbstractAssemblyMultibodyDynamicsAnalysis"],
        "_5398": ["AbstractShaftMultibodyDynamicsAnalysis"],
        "_5399": ["AbstractShaftOrHousingMultibodyDynamicsAnalysis"],
        "_5400": [
            "AbstractShaftToMountableComponentConnectionMultibodyDynamicsAnalysis"
        ],
        "_5401": ["AGMAGleasonConicalGearMeshMultibodyDynamicsAnalysis"],
        "_5402": ["AGMAGleasonConicalGearMultibodyDynamicsAnalysis"],
        "_5403": ["AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis"],
        "_5404": ["AnalysisTypes"],
        "_5405": ["AssemblyMultibodyDynamicsAnalysis"],
        "_5406": ["BearingMultibodyDynamicsAnalysis"],
        "_5407": ["BearingStiffnessModel"],
        "_5408": ["BeltConnectionMultibodyDynamicsAnalysis"],
        "_5409": ["BeltDriveMultibodyDynamicsAnalysis"],
        "_5410": ["BevelDifferentialGearMeshMultibodyDynamicsAnalysis"],
        "_5411": ["BevelDifferentialGearMultibodyDynamicsAnalysis"],
        "_5412": ["BevelDifferentialGearSetMultibodyDynamicsAnalysis"],
        "_5413": ["BevelDifferentialPlanetGearMultibodyDynamicsAnalysis"],
        "_5414": ["BevelDifferentialSunGearMultibodyDynamicsAnalysis"],
        "_5415": ["BevelGearMeshMultibodyDynamicsAnalysis"],
        "_5416": ["BevelGearMultibodyDynamicsAnalysis"],
        "_5417": ["BevelGearSetMultibodyDynamicsAnalysis"],
        "_5418": ["BoltedJointMultibodyDynamicsAnalysis"],
        "_5419": ["BoltMultibodyDynamicsAnalysis"],
        "_5420": ["ClutchConnectionMultibodyDynamicsAnalysis"],
        "_5421": ["ClutchHalfMultibodyDynamicsAnalysis"],
        "_5422": ["ClutchMultibodyDynamicsAnalysis"],
        "_5423": ["ClutchSpringType"],
        "_5424": ["CoaxialConnectionMultibodyDynamicsAnalysis"],
        "_5425": ["ComponentMultibodyDynamicsAnalysis"],
        "_5426": ["ConceptCouplingConnectionMultibodyDynamicsAnalysis"],
        "_5427": ["ConceptCouplingHalfMultibodyDynamicsAnalysis"],
        "_5428": ["ConceptCouplingMultibodyDynamicsAnalysis"],
        "_5429": ["ConceptGearMeshMultibodyDynamicsAnalysis"],
        "_5430": ["ConceptGearMultibodyDynamicsAnalysis"],
        "_5431": ["ConceptGearSetMultibodyDynamicsAnalysis"],
        "_5432": ["ConicalGearMeshMultibodyDynamicsAnalysis"],
        "_5433": ["ConicalGearMultibodyDynamicsAnalysis"],
        "_5434": ["ConicalGearSetMultibodyDynamicsAnalysis"],
        "_5435": ["ConnectionMultibodyDynamicsAnalysis"],
        "_5436": ["ConnectorMultibodyDynamicsAnalysis"],
        "_5437": ["CouplingConnectionMultibodyDynamicsAnalysis"],
        "_5438": ["CouplingHalfMultibodyDynamicsAnalysis"],
        "_5439": ["CouplingMultibodyDynamicsAnalysis"],
        "_5440": ["CVTBeltConnectionMultibodyDynamicsAnalysis"],
        "_5441": ["CVTMultibodyDynamicsAnalysis"],
        "_5442": ["CVTPulleyMultibodyDynamicsAnalysis"],
        "_5443": ["CycloidalAssemblyMultibodyDynamicsAnalysis"],
        "_5444": ["CycloidalDiscCentralBearingConnectionMultibodyDynamicsAnalysis"],
        "_5445": ["CycloidalDiscMultibodyDynamicsAnalysis"],
        "_5446": ["CycloidalDiscPlanetaryBearingConnectionMultibodyDynamicsAnalysis"],
        "_5447": ["CylindricalGearMeshMultibodyDynamicsAnalysis"],
        "_5448": ["CylindricalGearMultibodyDynamicsAnalysis"],
        "_5449": ["CylindricalGearSetMultibodyDynamicsAnalysis"],
        "_5450": ["CylindricalPlanetGearMultibodyDynamicsAnalysis"],
        "_5451": ["DatumMultibodyDynamicsAnalysis"],
        "_5452": ["ExternalCADModelMultibodyDynamicsAnalysis"],
        "_5453": ["FaceGearMeshMultibodyDynamicsAnalysis"],
        "_5454": ["FaceGearMultibodyDynamicsAnalysis"],
        "_5455": ["FaceGearSetMultibodyDynamicsAnalysis"],
        "_5456": ["FEPartMultibodyDynamicsAnalysis"],
        "_5457": ["FlexiblePinAssemblyMultibodyDynamicsAnalysis"],
        "_5458": ["GearMeshMultibodyDynamicsAnalysis"],
        "_5459": ["GearMeshStiffnessModel"],
        "_5460": ["GearMultibodyDynamicsAnalysis"],
        "_5461": ["GearSetMultibodyDynamicsAnalysis"],
        "_5462": ["GuideDxfModelMultibodyDynamicsAnalysis"],
        "_5463": ["HypoidGearMeshMultibodyDynamicsAnalysis"],
        "_5464": ["HypoidGearMultibodyDynamicsAnalysis"],
        "_5465": ["HypoidGearSetMultibodyDynamicsAnalysis"],
        "_5466": ["InertiaAdjustedLoadCasePeriodMethod"],
        "_5467": ["InertiaAdjustedLoadCaseResultsToCreate"],
        "_5468": ["InputSignalFilterLevel"],
        "_5469": ["InputVelocityForRunUpProcessingType"],
        "_5470": ["InterMountableComponentConnectionMultibodyDynamicsAnalysis"],
        "_5471": ["KlingelnbergCycloPalloidConicalGearMeshMultibodyDynamicsAnalysis"],
        "_5472": ["KlingelnbergCycloPalloidConicalGearMultibodyDynamicsAnalysis"],
        "_5473": ["KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis"],
        "_5474": ["KlingelnbergCycloPalloidHypoidGearMeshMultibodyDynamicsAnalysis"],
        "_5475": ["KlingelnbergCycloPalloidHypoidGearMultibodyDynamicsAnalysis"],
        "_5476": ["KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis"],
        "_5477": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshMultibodyDynamicsAnalysis"
        ],
        "_5478": ["KlingelnbergCycloPalloidSpiralBevelGearMultibodyDynamicsAnalysis"],
        "_5479": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis"
        ],
        "_5480": ["MassDiscMultibodyDynamicsAnalysis"],
        "_5481": ["MBDAnalysisDrawStyle"],
        "_5482": ["MBDAnalysisOptions"],
        "_5483": ["MBDRunUpAnalysisOptions"],
        "_5484": ["MeasurementComponentMultibodyDynamicsAnalysis"],
        "_5485": ["MountableComponentMultibodyDynamicsAnalysis"],
        "_5486": ["MultibodyDynamicsAnalysis"],
        "_5487": ["OilSealMultibodyDynamicsAnalysis"],
        "_5488": ["PartMultibodyDynamicsAnalysis"],
        "_5489": ["PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis"],
        "_5490": ["PartToPartShearCouplingHalfMultibodyDynamicsAnalysis"],
        "_5491": ["PartToPartShearCouplingMultibodyDynamicsAnalysis"],
        "_5492": ["PlanetaryConnectionMultibodyDynamicsAnalysis"],
        "_5493": ["PlanetaryGearSetMultibodyDynamicsAnalysis"],
        "_5494": ["PlanetCarrierMultibodyDynamicsAnalysis"],
        "_5495": ["PointLoadMultibodyDynamicsAnalysis"],
        "_5496": ["PowerLoadMultibodyDynamicsAnalysis"],
        "_5497": ["PulleyMultibodyDynamicsAnalysis"],
        "_5498": ["RingPinsMultibodyDynamicsAnalysis"],
        "_5499": ["RingPinsToDiscConnectionMultibodyDynamicsAnalysis"],
        "_5500": ["RollingRingAssemblyMultibodyDynamicsAnalysis"],
        "_5501": ["RollingRingConnectionMultibodyDynamicsAnalysis"],
        "_5502": ["RollingRingMultibodyDynamicsAnalysis"],
        "_5503": ["RootAssemblyMultibodyDynamicsAnalysis"],
        "_5504": ["RunUpDrivingMode"],
        "_5505": ["ShaftAndHousingFlexibilityOption"],
        "_5506": ["ShaftHubConnectionMultibodyDynamicsAnalysis"],
        "_5507": ["ShaftMultibodyDynamicsAnalysis"],
        "_5508": ["ShaftToMountableComponentConnectionMultibodyDynamicsAnalysis"],
        "_5509": ["ShapeOfInitialAccelerationPeriodForRunUp"],
        "_5510": ["SpecialisedAssemblyMultibodyDynamicsAnalysis"],
        "_5511": ["SpiralBevelGearMeshMultibodyDynamicsAnalysis"],
        "_5512": ["SpiralBevelGearMultibodyDynamicsAnalysis"],
        "_5513": ["SpiralBevelGearSetMultibodyDynamicsAnalysis"],
        "_5514": ["SpringDamperConnectionMultibodyDynamicsAnalysis"],
        "_5515": ["SpringDamperHalfMultibodyDynamicsAnalysis"],
        "_5516": ["SpringDamperMultibodyDynamicsAnalysis"],
        "_5517": ["StraightBevelDiffGearMeshMultibodyDynamicsAnalysis"],
        "_5518": ["StraightBevelDiffGearMultibodyDynamicsAnalysis"],
        "_5519": ["StraightBevelDiffGearSetMultibodyDynamicsAnalysis"],
        "_5520": ["StraightBevelGearMeshMultibodyDynamicsAnalysis"],
        "_5521": ["StraightBevelGearMultibodyDynamicsAnalysis"],
        "_5522": ["StraightBevelGearSetMultibodyDynamicsAnalysis"],
        "_5523": ["StraightBevelPlanetGearMultibodyDynamicsAnalysis"],
        "_5524": ["StraightBevelSunGearMultibodyDynamicsAnalysis"],
        "_5525": ["SynchroniserHalfMultibodyDynamicsAnalysis"],
        "_5526": ["SynchroniserMultibodyDynamicsAnalysis"],
        "_5527": ["SynchroniserPartMultibodyDynamicsAnalysis"],
        "_5528": ["SynchroniserSleeveMultibodyDynamicsAnalysis"],
        "_5529": ["TorqueConverterConnectionMultibodyDynamicsAnalysis"],
        "_5530": ["TorqueConverterLockupRule"],
        "_5531": ["TorqueConverterMultibodyDynamicsAnalysis"],
        "_5532": ["TorqueConverterPumpMultibodyDynamicsAnalysis"],
        "_5533": ["TorqueConverterStatus"],
        "_5534": ["TorqueConverterTurbineMultibodyDynamicsAnalysis"],
        "_5535": ["UnbalancedMassMultibodyDynamicsAnalysis"],
        "_5536": ["VirtualComponentMultibodyDynamicsAnalysis"],
        "_5537": ["WheelSlipType"],
        "_5538": ["WormGearMeshMultibodyDynamicsAnalysis"],
        "_5539": ["WormGearMultibodyDynamicsAnalysis"],
        "_5540": ["WormGearSetMultibodyDynamicsAnalysis"],
        "_5541": ["ZerolBevelGearMeshMultibodyDynamicsAnalysis"],
        "_5542": ["ZerolBevelGearMultibodyDynamicsAnalysis"],
        "_5543": ["ZerolBevelGearSetMultibodyDynamicsAnalysis"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "AbstractAssemblyMultibodyDynamicsAnalysis",
    "AbstractShaftMultibodyDynamicsAnalysis",
    "AbstractShaftOrHousingMultibodyDynamicsAnalysis",
    "AbstractShaftToMountableComponentConnectionMultibodyDynamicsAnalysis",
    "AGMAGleasonConicalGearMeshMultibodyDynamicsAnalysis",
    "AGMAGleasonConicalGearMultibodyDynamicsAnalysis",
    "AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis",
    "AnalysisTypes",
    "AssemblyMultibodyDynamicsAnalysis",
    "BearingMultibodyDynamicsAnalysis",
    "BearingStiffnessModel",
    "BeltConnectionMultibodyDynamicsAnalysis",
    "BeltDriveMultibodyDynamicsAnalysis",
    "BevelDifferentialGearMeshMultibodyDynamicsAnalysis",
    "BevelDifferentialGearMultibodyDynamicsAnalysis",
    "BevelDifferentialGearSetMultibodyDynamicsAnalysis",
    "BevelDifferentialPlanetGearMultibodyDynamicsAnalysis",
    "BevelDifferentialSunGearMultibodyDynamicsAnalysis",
    "BevelGearMeshMultibodyDynamicsAnalysis",
    "BevelGearMultibodyDynamicsAnalysis",
    "BevelGearSetMultibodyDynamicsAnalysis",
    "BoltedJointMultibodyDynamicsAnalysis",
    "BoltMultibodyDynamicsAnalysis",
    "ClutchConnectionMultibodyDynamicsAnalysis",
    "ClutchHalfMultibodyDynamicsAnalysis",
    "ClutchMultibodyDynamicsAnalysis",
    "ClutchSpringType",
    "CoaxialConnectionMultibodyDynamicsAnalysis",
    "ComponentMultibodyDynamicsAnalysis",
    "ConceptCouplingConnectionMultibodyDynamicsAnalysis",
    "ConceptCouplingHalfMultibodyDynamicsAnalysis",
    "ConceptCouplingMultibodyDynamicsAnalysis",
    "ConceptGearMeshMultibodyDynamicsAnalysis",
    "ConceptGearMultibodyDynamicsAnalysis",
    "ConceptGearSetMultibodyDynamicsAnalysis",
    "ConicalGearMeshMultibodyDynamicsAnalysis",
    "ConicalGearMultibodyDynamicsAnalysis",
    "ConicalGearSetMultibodyDynamicsAnalysis",
    "ConnectionMultibodyDynamicsAnalysis",
    "ConnectorMultibodyDynamicsAnalysis",
    "CouplingConnectionMultibodyDynamicsAnalysis",
    "CouplingHalfMultibodyDynamicsAnalysis",
    "CouplingMultibodyDynamicsAnalysis",
    "CVTBeltConnectionMultibodyDynamicsAnalysis",
    "CVTMultibodyDynamicsAnalysis",
    "CVTPulleyMultibodyDynamicsAnalysis",
    "CycloidalAssemblyMultibodyDynamicsAnalysis",
    "CycloidalDiscCentralBearingConnectionMultibodyDynamicsAnalysis",
    "CycloidalDiscMultibodyDynamicsAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionMultibodyDynamicsAnalysis",
    "CylindricalGearMeshMultibodyDynamicsAnalysis",
    "CylindricalGearMultibodyDynamicsAnalysis",
    "CylindricalGearSetMultibodyDynamicsAnalysis",
    "CylindricalPlanetGearMultibodyDynamicsAnalysis",
    "DatumMultibodyDynamicsAnalysis",
    "ExternalCADModelMultibodyDynamicsAnalysis",
    "FaceGearMeshMultibodyDynamicsAnalysis",
    "FaceGearMultibodyDynamicsAnalysis",
    "FaceGearSetMultibodyDynamicsAnalysis",
    "FEPartMultibodyDynamicsAnalysis",
    "FlexiblePinAssemblyMultibodyDynamicsAnalysis",
    "GearMeshMultibodyDynamicsAnalysis",
    "GearMeshStiffnessModel",
    "GearMultibodyDynamicsAnalysis",
    "GearSetMultibodyDynamicsAnalysis",
    "GuideDxfModelMultibodyDynamicsAnalysis",
    "HypoidGearMeshMultibodyDynamicsAnalysis",
    "HypoidGearMultibodyDynamicsAnalysis",
    "HypoidGearSetMultibodyDynamicsAnalysis",
    "InertiaAdjustedLoadCasePeriodMethod",
    "InertiaAdjustedLoadCaseResultsToCreate",
    "InputSignalFilterLevel",
    "InputVelocityForRunUpProcessingType",
    "InterMountableComponentConnectionMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidConicalGearMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis",
    "MassDiscMultibodyDynamicsAnalysis",
    "MBDAnalysisDrawStyle",
    "MBDAnalysisOptions",
    "MBDRunUpAnalysisOptions",
    "MeasurementComponentMultibodyDynamicsAnalysis",
    "MountableComponentMultibodyDynamicsAnalysis",
    "MultibodyDynamicsAnalysis",
    "OilSealMultibodyDynamicsAnalysis",
    "PartMultibodyDynamicsAnalysis",
    "PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis",
    "PartToPartShearCouplingHalfMultibodyDynamicsAnalysis",
    "PartToPartShearCouplingMultibodyDynamicsAnalysis",
    "PlanetaryConnectionMultibodyDynamicsAnalysis",
    "PlanetaryGearSetMultibodyDynamicsAnalysis",
    "PlanetCarrierMultibodyDynamicsAnalysis",
    "PointLoadMultibodyDynamicsAnalysis",
    "PowerLoadMultibodyDynamicsAnalysis",
    "PulleyMultibodyDynamicsAnalysis",
    "RingPinsMultibodyDynamicsAnalysis",
    "RingPinsToDiscConnectionMultibodyDynamicsAnalysis",
    "RollingRingAssemblyMultibodyDynamicsAnalysis",
    "RollingRingConnectionMultibodyDynamicsAnalysis",
    "RollingRingMultibodyDynamicsAnalysis",
    "RootAssemblyMultibodyDynamicsAnalysis",
    "RunUpDrivingMode",
    "ShaftAndHousingFlexibilityOption",
    "ShaftHubConnectionMultibodyDynamicsAnalysis",
    "ShaftMultibodyDynamicsAnalysis",
    "ShaftToMountableComponentConnectionMultibodyDynamicsAnalysis",
    "ShapeOfInitialAccelerationPeriodForRunUp",
    "SpecialisedAssemblyMultibodyDynamicsAnalysis",
    "SpiralBevelGearMeshMultibodyDynamicsAnalysis",
    "SpiralBevelGearMultibodyDynamicsAnalysis",
    "SpiralBevelGearSetMultibodyDynamicsAnalysis",
    "SpringDamperConnectionMultibodyDynamicsAnalysis",
    "SpringDamperHalfMultibodyDynamicsAnalysis",
    "SpringDamperMultibodyDynamicsAnalysis",
    "StraightBevelDiffGearMeshMultibodyDynamicsAnalysis",
    "StraightBevelDiffGearMultibodyDynamicsAnalysis",
    "StraightBevelDiffGearSetMultibodyDynamicsAnalysis",
    "StraightBevelGearMeshMultibodyDynamicsAnalysis",
    "StraightBevelGearMultibodyDynamicsAnalysis",
    "StraightBevelGearSetMultibodyDynamicsAnalysis",
    "StraightBevelPlanetGearMultibodyDynamicsAnalysis",
    "StraightBevelSunGearMultibodyDynamicsAnalysis",
    "SynchroniserHalfMultibodyDynamicsAnalysis",
    "SynchroniserMultibodyDynamicsAnalysis",
    "SynchroniserPartMultibodyDynamicsAnalysis",
    "SynchroniserSleeveMultibodyDynamicsAnalysis",
    "TorqueConverterConnectionMultibodyDynamicsAnalysis",
    "TorqueConverterLockupRule",
    "TorqueConverterMultibodyDynamicsAnalysis",
    "TorqueConverterPumpMultibodyDynamicsAnalysis",
    "TorqueConverterStatus",
    "TorqueConverterTurbineMultibodyDynamicsAnalysis",
    "UnbalancedMassMultibodyDynamicsAnalysis",
    "VirtualComponentMultibodyDynamicsAnalysis",
    "WheelSlipType",
    "WormGearMeshMultibodyDynamicsAnalysis",
    "WormGearMultibodyDynamicsAnalysis",
    "WormGearSetMultibodyDynamicsAnalysis",
    "ZerolBevelGearMeshMultibodyDynamicsAnalysis",
    "ZerolBevelGearMultibodyDynamicsAnalysis",
    "ZerolBevelGearSetMultibodyDynamicsAnalysis",
)



"""GearCutterSimulation"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_GEAR_CUTTER_SIMULATION = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.CutterSimulation",
    "GearCutterSimulation",
)

if TYPE_CHECKING:
    from mastapy.gears.manufacturing.cylindrical.cutter_simulation import (
        _734,
        _750,
        _737,
        _738,
        _739,
        _747,
    )


__docformat__ = "restructuredtext en"
__all__ = ("GearCutterSimulation",)


Self = TypeVar("Self", bound="GearCutterSimulation")


class GearCutterSimulation(_0.APIBase):
    """GearCutterSimulation

    This is a mastapy class.
    """

    TYPE = _GEAR_CUTTER_SIMULATION
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_GearCutterSimulation")

    class _Cast_GearCutterSimulation:
        """Special nested class for casting GearCutterSimulation to subclasses."""

        def __init__(
            self: "GearCutterSimulation._Cast_GearCutterSimulation",
            parent: "GearCutterSimulation",
        ):
            self._parent = parent

        @property
        def finish_cutter_simulation(
            self: "GearCutterSimulation._Cast_GearCutterSimulation",
        ) -> "_739.FinishCutterSimulation":
            from mastapy.gears.manufacturing.cylindrical.cutter_simulation import _739

            return self._parent._cast(_739.FinishCutterSimulation)

        @property
        def rough_cutter_simulation(
            self: "GearCutterSimulation._Cast_GearCutterSimulation",
        ) -> "_747.RoughCutterSimulation":
            from mastapy.gears.manufacturing.cylindrical.cutter_simulation import _747

            return self._parent._cast(_747.RoughCutterSimulation)

        @property
        def gear_cutter_simulation(
            self: "GearCutterSimulation._Cast_GearCutterSimulation",
        ) -> "GearCutterSimulation":
            return self._parent

        def __getattr__(
            self: "GearCutterSimulation._Cast_GearCutterSimulation", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "GearCutterSimulation.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def highest_finished_form_diameter(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HighestFinishedFormDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def least_sap_to_form_radius_clearance(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LeastSAPToFormRadiusClearance

        if temp is None:
            return 0.0

        return temp

    @property
    def lowest_finished_tip_form_diameter(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LowestFinishedTipFormDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def name(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Name

        if temp is None:
            return ""

        return temp

    @property
    def average_thickness(self: Self) -> "_734.CutterSimulationCalc":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.CutterSimulationCalc

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AverageThickness

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def average_thickness_virtual(self: Self) -> "_750.VirtualSimulationCalculator":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.VirtualSimulationCalculator

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AverageThicknessVirtual

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def least_profile(self: Self) -> "_734.CutterSimulationCalc":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.CutterSimulationCalc

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LeastProfile

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def least_profile_virtual(self: Self) -> "_750.VirtualSimulationCalculator":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.VirtualSimulationCalculator

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LeastProfileVirtual

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def maximum_thickness(self: Self) -> "_734.CutterSimulationCalc":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.CutterSimulationCalc

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumThickness

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def maximum_thickness_virtual(self: Self) -> "_750.VirtualSimulationCalculator":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.VirtualSimulationCalculator

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumThicknessVirtual

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def minimum_thickness(self: Self) -> "_734.CutterSimulationCalc":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.CutterSimulationCalc

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumThickness

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def minimum_thickness_virtual(self: Self) -> "_750.VirtualSimulationCalculator":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.VirtualSimulationCalculator

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumThicknessVirtual

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cutter_simulation(self: Self) -> "GearCutterSimulation":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.GearCutterSimulation

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CutterSimulation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def gear_mesh_cutter_simulations(
        self: Self,
    ) -> "List[_737.CylindricalManufacturedRealGearInMesh]":
        """List[mastapy.gears.manufacturing.cylindrical.cutter_simulation.CylindricalManufacturedRealGearInMesh]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearMeshCutterSimulations

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def gear_mesh_cutter_simulations_virtual(
        self: Self,
    ) -> "List[_738.CylindricalManufacturedVirtualGearInMesh]":
        """List[mastapy.gears.manufacturing.cylindrical.cutter_simulation.CylindricalManufacturedVirtualGearInMesh]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearMeshCutterSimulationsVirtual

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def thickness_calculators(self: Self) -> "List[_734.CutterSimulationCalc]":
        """List[mastapy.gears.manufacturing.cylindrical.cutter_simulation.CutterSimulationCalc]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ThicknessCalculators

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def virtual_thickness_calculators(
        self: Self,
    ) -> "List[_750.VirtualSimulationCalculator]":
        """List[mastapy.gears.manufacturing.cylindrical.cutter_simulation.VirtualSimulationCalculator]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.VirtualThicknessCalculators

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def report_names(self: Self) -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(self: Self, report_name: "str", file_path: "str"):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: Self, report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(self: Self) -> "GearCutterSimulation._Cast_GearCutterSimulation":
        return self._Cast_GearCutterSimulation(self)



"""SpeedPointsDistribution"""
from __future__ import annotations

from typing import TypeVar, Any
from enum import Enum

from mastapy._internal.python_net import python_net_import

_SPEED_POINTS_DISTRIBUTION = python_net_import(
    "SMT.MastaAPI.ElectricMachines.LoadCasesAndAnalyses", "SpeedPointsDistribution"
)


__docformat__ = "restructuredtext en"
__all__ = ("SpeedPointsDistribution",)


Self = TypeVar("Self", bound="SpeedPointsDistribution")


class SpeedPointsDistribution(Enum):
    """SpeedPointsDistribution

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _SPEED_POINTS_DISTRIBUTION

    LINEAR = 0
    USERDEFINED = 1


def __enum_setattr(self: Self, attr: str, value: Any):
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: Self, attr: str):
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


SpeedPointsDistribution.__setattr__ = __enum_setattr
SpeedPointsDistribution.__delattr__ = __enum_delattr



"""ConnectionHarmonicAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.analysis_cases import _7562
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_CONNECTION_HARMONIC_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses",
    "ConnectionHarmonicAnalysis",
)

if TYPE_CHECKING:
    from mastapy.system_model.connections_and_sockets import _2292
    from mastapy.system_model.analyses_and_results.harmonic_analyses import (
        _5782,
        _5703,
        _5705,
        _5709,
        _5712,
        _5717,
        _5721,
        _5724,
        _5727,
        _5731,
        _5734,
        _5738,
        _5741,
        _5745,
        _5747,
        _5749,
        _5769,
        _5776,
        _5793,
        _5795,
        _5797,
        _5800,
        _5803,
        _5810,
        _5814,
        _5822,
        _5824,
        _5829,
        _5834,
        _5836,
        _5841,
        _5844,
        _5852,
        _5860,
        _5863,
    )
    from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
        _6091,
    )
    from mastapy.system_model.analyses_and_results.system_deflections import _2748
    from mastapy.system_model.analyses_and_results.analysis_cases import _7559
    from mastapy.system_model.analyses_and_results import _2670, _2674, _2672


__docformat__ = "restructuredtext en"
__all__ = ("ConnectionHarmonicAnalysis",)


Self = TypeVar("Self", bound="ConnectionHarmonicAnalysis")


class ConnectionHarmonicAnalysis(_7562.ConnectionStaticLoadAnalysisCase):
    """ConnectionHarmonicAnalysis

    This is a mastapy class.
    """

    TYPE = _CONNECTION_HARMONIC_ANALYSIS
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_ConnectionHarmonicAnalysis")

    class _Cast_ConnectionHarmonicAnalysis:
        """Special nested class for casting ConnectionHarmonicAnalysis to subclasses."""

        def __init__(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
            parent: "ConnectionHarmonicAnalysis",
        ):
            self._parent = parent

        @property
        def connection_static_load_analysis_case(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_7562.ConnectionStaticLoadAnalysisCase":
            return self._parent._cast(_7562.ConnectionStaticLoadAnalysisCase)

        @property
        def connection_analysis_case(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_7559.ConnectionAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7559

            return self._parent._cast(_7559.ConnectionAnalysisCase)

        @property
        def connection_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_2670.ConnectionAnalysis":
            from mastapy.system_model.analyses_and_results import _2670

            return self._parent._cast(_2670.ConnectionAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_2674.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2674

            return self._parent._cast(_2674.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_2672.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2672

            return self._parent._cast(_2672.DesignEntityAnalysis)

        @property
        def abstract_shaft_to_mountable_component_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5703.AbstractShaftToMountableComponentConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5703,
            )

            return self._parent._cast(
                _5703.AbstractShaftToMountableComponentConnectionHarmonicAnalysis
            )

        @property
        def agma_gleason_conical_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5705.AGMAGleasonConicalGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5705,
            )

            return self._parent._cast(_5705.AGMAGleasonConicalGearMeshHarmonicAnalysis)

        @property
        def belt_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5709.BeltConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5709,
            )

            return self._parent._cast(_5709.BeltConnectionHarmonicAnalysis)

        @property
        def bevel_differential_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5712.BevelDifferentialGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5712,
            )

            return self._parent._cast(_5712.BevelDifferentialGearMeshHarmonicAnalysis)

        @property
        def bevel_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5717.BevelGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5717,
            )

            return self._parent._cast(_5717.BevelGearMeshHarmonicAnalysis)

        @property
        def clutch_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5721.ClutchConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5721,
            )

            return self._parent._cast(_5721.ClutchConnectionHarmonicAnalysis)

        @property
        def coaxial_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5724.CoaxialConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5724,
            )

            return self._parent._cast(_5724.CoaxialConnectionHarmonicAnalysis)

        @property
        def concept_coupling_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5727.ConceptCouplingConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5727,
            )

            return self._parent._cast(_5727.ConceptCouplingConnectionHarmonicAnalysis)

        @property
        def concept_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5731.ConceptGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5731,
            )

            return self._parent._cast(_5731.ConceptGearMeshHarmonicAnalysis)

        @property
        def conical_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5734.ConicalGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5734,
            )

            return self._parent._cast(_5734.ConicalGearMeshHarmonicAnalysis)

        @property
        def coupling_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5738.CouplingConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5738,
            )

            return self._parent._cast(_5738.CouplingConnectionHarmonicAnalysis)

        @property
        def cvt_belt_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5741.CVTBeltConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5741,
            )

            return self._parent._cast(_5741.CVTBeltConnectionHarmonicAnalysis)

        @property
        def cycloidal_disc_central_bearing_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5745.CycloidalDiscCentralBearingConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5745,
            )

            return self._parent._cast(
                _5745.CycloidalDiscCentralBearingConnectionHarmonicAnalysis
            )

        @property
        def cycloidal_disc_planetary_bearing_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5747.CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5747,
            )

            return self._parent._cast(
                _5747.CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis
            )

        @property
        def cylindrical_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5749.CylindricalGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5749,
            )

            return self._parent._cast(_5749.CylindricalGearMeshHarmonicAnalysis)

        @property
        def face_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5769.FaceGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5769,
            )

            return self._parent._cast(_5769.FaceGearMeshHarmonicAnalysis)

        @property
        def gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5776.GearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5776,
            )

            return self._parent._cast(_5776.GearMeshHarmonicAnalysis)

        @property
        def hypoid_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5793.HypoidGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5793,
            )

            return self._parent._cast(_5793.HypoidGearMeshHarmonicAnalysis)

        @property
        def inter_mountable_component_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5795.InterMountableComponentConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5795,
            )

            return self._parent._cast(
                _5795.InterMountableComponentConnectionHarmonicAnalysis
            )

        @property
        def klingelnberg_cyclo_palloid_conical_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5797.KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5797,
            )

            return self._parent._cast(
                _5797.KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis
            )

        @property
        def klingelnberg_cyclo_palloid_hypoid_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5800.KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5800,
            )

            return self._parent._cast(
                _5800.KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis
            )

        @property
        def klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5803.KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5803,
            )

            return self._parent._cast(
                _5803.KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis
            )

        @property
        def part_to_part_shear_coupling_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5810.PartToPartShearCouplingConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5810,
            )

            return self._parent._cast(
                _5810.PartToPartShearCouplingConnectionHarmonicAnalysis
            )

        @property
        def planetary_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5814.PlanetaryConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5814,
            )

            return self._parent._cast(_5814.PlanetaryConnectionHarmonicAnalysis)

        @property
        def ring_pins_to_disc_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5822.RingPinsToDiscConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5822,
            )

            return self._parent._cast(_5822.RingPinsToDiscConnectionHarmonicAnalysis)

        @property
        def rolling_ring_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5824.RollingRingConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5824,
            )

            return self._parent._cast(_5824.RollingRingConnectionHarmonicAnalysis)

        @property
        def shaft_to_mountable_component_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5829.ShaftToMountableComponentConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5829,
            )

            return self._parent._cast(
                _5829.ShaftToMountableComponentConnectionHarmonicAnalysis
            )

        @property
        def spiral_bevel_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5834.SpiralBevelGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5834,
            )

            return self._parent._cast(_5834.SpiralBevelGearMeshHarmonicAnalysis)

        @property
        def spring_damper_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5836.SpringDamperConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5836,
            )

            return self._parent._cast(_5836.SpringDamperConnectionHarmonicAnalysis)

        @property
        def straight_bevel_diff_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5841.StraightBevelDiffGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5841,
            )

            return self._parent._cast(_5841.StraightBevelDiffGearMeshHarmonicAnalysis)

        @property
        def straight_bevel_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5844.StraightBevelGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5844,
            )

            return self._parent._cast(_5844.StraightBevelGearMeshHarmonicAnalysis)

        @property
        def torque_converter_connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5852.TorqueConverterConnectionHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5852,
            )

            return self._parent._cast(_5852.TorqueConverterConnectionHarmonicAnalysis)

        @property
        def worm_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5860.WormGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5860,
            )

            return self._parent._cast(_5860.WormGearMeshHarmonicAnalysis)

        @property
        def zerol_bevel_gear_mesh_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "_5863.ZerolBevelGearMeshHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5863,
            )

            return self._parent._cast(_5863.ZerolBevelGearMeshHarmonicAnalysis)

        @property
        def connection_harmonic_analysis(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
        ) -> "ConnectionHarmonicAnalysis":
            return self._parent

        def __getattr__(
            self: "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "ConnectionHarmonicAnalysis.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self: Self) -> "_2292.Connection":
        """mastapy.system_model.connections_and_sockets.Connection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def connection_design(self: Self) -> "_2292.Connection":
        """mastapy.system_model.connections_and_sockets.Connection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def harmonic_analysis(self: Self) -> "_5782.HarmonicAnalysis":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.HarmonicAnalysis

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HarmonicAnalysis

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def harmonic_analyses_of_single_excitations(
        self: Self,
    ) -> "List[_6091.HarmonicAnalysisOfSingleExcitation]":
        """List[mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation.HarmonicAnalysisOfSingleExcitation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HarmonicAnalysesOfSingleExcitations

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def system_deflection_results(self: Self) -> "_2748.ConnectionSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.ConnectionSystemDeflection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SystemDeflectionResults

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "ConnectionHarmonicAnalysis._Cast_ConnectionHarmonicAnalysis":
        return self._Cast_ConnectionHarmonicAnalysis(self)



"""WormGearRating"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.gears.rating import _364
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_WORM_GEAR_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Worm", "WormGearRating"
)

if TYPE_CHECKING:
    from mastapy.gears.rating import _362, _357
    from mastapy.gears.gear_designs.worm import _961
    from mastapy.gears.analysis import _1233


__docformat__ = "restructuredtext en"
__all__ = ("WormGearRating",)


Self = TypeVar("Self", bound="WormGearRating")


class WormGearRating(_364.GearRating):
    """WormGearRating

    This is a mastapy class.
    """

    TYPE = _WORM_GEAR_RATING
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_WormGearRating")

    class _Cast_WormGearRating:
        """Special nested class for casting WormGearRating to subclasses."""

        def __init__(
            self: "WormGearRating._Cast_WormGearRating", parent: "WormGearRating"
        ):
            self._parent = parent

        @property
        def gear_rating(
            self: "WormGearRating._Cast_WormGearRating",
        ) -> "_364.GearRating":
            return self._parent._cast(_364.GearRating)

        @property
        def abstract_gear_rating(
            self: "WormGearRating._Cast_WormGearRating",
        ) -> "_357.AbstractGearRating":
            from mastapy.gears.rating import _357

            return self._parent._cast(_357.AbstractGearRating)

        @property
        def abstract_gear_analysis(
            self: "WormGearRating._Cast_WormGearRating",
        ) -> "_1233.AbstractGearAnalysis":
            from mastapy.gears.analysis import _1233

            return self._parent._cast(_1233.AbstractGearAnalysis)

        @property
        def worm_gear_rating(
            self: "WormGearRating._Cast_WormGearRating",
        ) -> "WormGearRating":
            return self._parent

        def __getattr__(self: "WormGearRating._Cast_WormGearRating", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "WormGearRating.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def left_flank_rating(self: Self) -> "_362.GearFlankRating":
        """mastapy.gears.rating.GearFlankRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LeftFlankRating

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def right_flank_rating(self: Self) -> "_362.GearFlankRating":
        """mastapy.gears.rating.GearFlankRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RightFlankRating

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def worm_gear(self: Self) -> "_961.WormGearDesign":
        """mastapy.gears.gear_designs.worm.WormGearDesign

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WormGear

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: Self) -> "WormGearRating._Cast_WormGearRating":
        return self._Cast_WormGearRating(self)



"""CylindricalGearMeshAdvancedSystemDeflection"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from PIL.Image import Image

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.advanced_system_deflections import _7355
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_MESH_ADVANCED_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections",
    "CylindricalGearMeshAdvancedSystemDeflection",
)

if TYPE_CHECKING:
    from mastapy.gears import _326
    from mastapy.gears.rating.cylindrical import _461
    from mastapy.system_model.connections_and_sockets.gears import _2329
    from mastapy.system_model.analyses_and_results.static_loads import _6885
    from mastapy.gears.gear_designs.cylindrical import _1028, _1022
    from mastapy.gears.cylindrical import _1232
    from mastapy.math_utility import _1531
    from mastapy.system_model.analyses_and_results.advanced_system_deflections import (
        _7342,
        _7331,
        _7361,
        _7329,
    )
    from mastapy.system_model.analyses_and_results.system_deflections import _2761
    from mastapy.system_model.analyses_and_results.analysis_cases import _7562, _7559
    from mastapy.system_model.analyses_and_results import _2670, _2674, _2672


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearMeshAdvancedSystemDeflection",)


Self = TypeVar("Self", bound="CylindricalGearMeshAdvancedSystemDeflection")


class CylindricalGearMeshAdvancedSystemDeflection(
    _7355.GearMeshAdvancedSystemDeflection
):
    """CylindricalGearMeshAdvancedSystemDeflection

    This is a mastapy class.
    """

    TYPE = _CYLINDRICAL_GEAR_MESH_ADVANCED_SYSTEM_DEFLECTION
    _CastSelf = TypeVar(
        "_CastSelf", bound="_Cast_CylindricalGearMeshAdvancedSystemDeflection"
    )

    class _Cast_CylindricalGearMeshAdvancedSystemDeflection:
        """Special nested class for casting CylindricalGearMeshAdvancedSystemDeflection to subclasses."""

        def __init__(
            self: "CylindricalGearMeshAdvancedSystemDeflection._Cast_CylindricalGearMeshAdvancedSystemDeflection",
            parent: "CylindricalGearMeshAdvancedSystemDeflection",
        ):
            self._parent = parent

        @property
        def gear_mesh_advanced_system_deflection(
            self: "CylindricalGearMeshAdvancedSystemDeflection._Cast_CylindricalGearMeshAdvancedSystemDeflection",
        ) -> "_7355.GearMeshAdvancedSystemDeflection":
            return self._parent._cast(_7355.GearMeshAdvancedSystemDeflection)

        @property
        def inter_mountable_component_connection_advanced_system_deflection(
            self: "CylindricalGearMeshAdvancedSystemDeflection._Cast_CylindricalGearMeshAdvancedSystemDeflection",
        ) -> "_7361.InterMountableComponentConnectionAdvancedSystemDeflection":
            from mastapy.system_model.analyses_and_results.advanced_system_deflections import (
                _7361,
            )

            return self._parent._cast(
                _7361.InterMountableComponentConnectionAdvancedSystemDeflection
            )

        @property
        def connection_advanced_system_deflection(
            self: "CylindricalGearMeshAdvancedSystemDeflection._Cast_CylindricalGearMeshAdvancedSystemDeflection",
        ) -> "_7329.ConnectionAdvancedSystemDeflection":
            from mastapy.system_model.analyses_and_results.advanced_system_deflections import (
                _7329,
            )

            return self._parent._cast(_7329.ConnectionAdvancedSystemDeflection)

        @property
        def connection_static_load_analysis_case(
            self: "CylindricalGearMeshAdvancedSystemDeflection._Cast_CylindricalGearMeshAdvancedSystemDeflection",
        ) -> "_7562.ConnectionStaticLoadAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7562

            return self._parent._cast(_7562.ConnectionStaticLoadAnalysisCase)

        @property
        def connection_analysis_case(
            self: "CylindricalGearMeshAdvancedSystemDeflection._Cast_CylindricalGearMeshAdvancedSystemDeflection",
        ) -> "_7559.ConnectionAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7559

            return self._parent._cast(_7559.ConnectionAnalysisCase)

        @property
        def connection_analysis(
            self: "CylindricalGearMeshAdvancedSystemDeflection._Cast_CylindricalGearMeshAdvancedSystemDeflection",
        ) -> "_2670.ConnectionAnalysis":
            from mastapy.system_model.analyses_and_results import _2670

            return self._parent._cast(_2670.ConnectionAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "CylindricalGearMeshAdvancedSystemDeflection._Cast_CylindricalGearMeshAdvancedSystemDeflection",
        ) -> "_2674.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2674

            return self._parent._cast(_2674.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "CylindricalGearMeshAdvancedSystemDeflection._Cast_CylindricalGearMeshAdvancedSystemDeflection",
        ) -> "_2672.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2672

            return self._parent._cast(_2672.DesignEntityAnalysis)

        @property
        def cylindrical_gear_mesh_advanced_system_deflection(
            self: "CylindricalGearMeshAdvancedSystemDeflection._Cast_CylindricalGearMeshAdvancedSystemDeflection",
        ) -> "CylindricalGearMeshAdvancedSystemDeflection":
            return self._parent

        def __getattr__(
            self: "CylindricalGearMeshAdvancedSystemDeflection._Cast_CylindricalGearMeshAdvancedSystemDeflection",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self, instance_to_wrap: "CylindricalGearMeshAdvancedSystemDeflection.TYPE"
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def active_flank(self: Self) -> "_326.CylindricalFlanks":
        """mastapy.gears.CylindricalFlanks

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ActiveFlank

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, "SMT.MastaAPI.Gears.CylindricalFlanks")

        if value is None:
            return None

        return constructor.new_from_mastapy("mastapy.gears._326", "CylindricalFlanks")(
            value
        )

    @property
    def average_operating_axial_contact_ratio_for_first_tooth_passing_period(
        self: Self,
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AverageOperatingAxialContactRatioForFirstToothPassingPeriod

        if temp is None:
            return 0.0

        return temp

    @property
    def average_operating_transverse_contact_ratio_for_first_tooth_passing_period(
        self: Self,
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.AverageOperatingTransverseContactRatioForFirstToothPassingPeriod
        )

        if temp is None:
            return 0.0

        return temp

    @property
    def calculated_load_sharing_factor(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CalculatedLoadSharingFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def contact_chart_gap_to_loaded_flank_gear_a(self: Self) -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactChartGapToLoadedFlankGearA

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def contact_chart_gap_to_loaded_flank_gear_a_as_text_file(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactChartGapToLoadedFlankGearAAsTextFile

        if temp is None:
            return ""

        return temp

    @property
    def contact_chart_gap_to_loaded_flank_gear_b(self: Self) -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactChartGapToLoadedFlankGearB

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def contact_chart_gap_to_loaded_flank_gear_b_as_text_file(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactChartGapToLoadedFlankGearBAsTextFile

        if temp is None:
            return ""

        return temp

    @property
    def contact_chart_gap_to_unloaded_flank_gear_a(self: Self) -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactChartGapToUnloadedFlankGearA

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def contact_chart_gap_to_unloaded_flank_gear_a_as_text_file(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactChartGapToUnloadedFlankGearAAsTextFile

        if temp is None:
            return ""

        return temp

    @property
    def contact_chart_gap_to_unloaded_flank_gear_b(self: Self) -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactChartGapToUnloadedFlankGearB

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def contact_chart_gap_to_unloaded_flank_gear_b_as_text_file(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactChartGapToUnloadedFlankGearBAsTextFile

        if temp is None:
            return ""

        return temp

    @property
    def contact_chart_max_pressure_gear_a(self: Self) -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactChartMaxPressureGearA

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def contact_chart_max_pressure_gear_a_as_text_file(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactChartMaxPressureGearAAsTextFile

        if temp is None:
            return ""

        return temp

    @property
    def contact_chart_max_pressure_gear_b(self: Self) -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactChartMaxPressureGearB

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def contact_chart_max_pressure_gear_b_as_text_file(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactChartMaxPressureGearBAsTextFile

        if temp is None:
            return ""

        return temp

    @property
    def face_load_factor_contact(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FaceLoadFactorContact

        if temp is None:
            return 0.0

        return temp

    @property
    def inactive_flank(self: Self) -> "_326.CylindricalFlanks":
        """mastapy.gears.CylindricalFlanks

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InactiveFlank

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, "SMT.MastaAPI.Gears.CylindricalFlanks")

        if value is None:
            return None

        return constructor.new_from_mastapy("mastapy.gears._326", "CylindricalFlanks")(
            value
        )

    @property
    def maximum_contact_pressure(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumContactPressure

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_edge_stress(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumEdgeStress

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_edge_stress_including_tip_contact(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumEdgeStressIncludingTipContact

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_edge_stress_on_gear_a_including_tip_contact(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumEdgeStressOnGearAIncludingTipContact

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_edge_stress_on_gear_b_including_tip_contact(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumEdgeStressOnGearBIncludingTipContact

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_principal_root_stress_on_tension_side_from_gear_fe_model(
        self: Self,
    ) -> "List[float]":
        """List[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumPrincipalRootStressOnTensionSideFromGearFEModel

        if temp is None:
            return None

        value = conversion.to_list_any(temp)

        if value is None:
            return None

        return value

    @property
    def mean_mesh_stiffness(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanMeshStiffness

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_mesh_tilt_stiffness(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanMeshTiltStiffness

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_te_excluding_backlash(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanTEExcludingBacklash

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_total_contact_ratio(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanTotalContactRatio

        if temp is None:
            return 0.0

        return temp

    @property
    def peak_to_peak_mesh_stiffness(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PeakToPeakMeshStiffness

        if temp is None:
            return 0.0

        return temp

    @property
    def peak_to_peak_te(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PeakToPeakTE

        if temp is None:
            return 0.0

        return temp

    @property
    def torque_share(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TorqueShare

        if temp is None:
            return 0.0

        return temp

    @property
    def use_advanced_ltca(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.UseAdvancedLTCA

        if temp is None:
            return False

        return temp

    @use_advanced_ltca.setter
    @enforce_parameter_types
    def use_advanced_ltca(self: Self, value: "bool"):
        self.wrapped.UseAdvancedLTCA = bool(value) if value is not None else False

    @property
    def component_detailed_analysis(self: Self) -> "_461.CylindricalGearMeshRating":
        """mastapy.gears.rating.cylindrical.CylindricalGearMeshRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDetailedAnalysis

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def connection_design(self: Self) -> "_2329.CylindricalGearMesh":
        """mastapy.system_model.connections_and_sockets.gears.CylindricalGearMesh

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def connection_load_case(self: Self) -> "_6885.CylindricalGearMeshLoadCase":
        """mastapy.system_model.analyses_and_results.static_loads.CylindricalGearMeshLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def gear_mesh_design(self: Self) -> "_1028.CylindricalGearMeshDesign":
        """mastapy.gears.gear_designs.cylindrical.CylindricalGearMeshDesign

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearMeshDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def points_with_worst_results(self: Self) -> "_1232.PointsWithWorstResults":
        """mastapy.gears.cylindrical.PointsWithWorstResults

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PointsWithWorstResults

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def transmission_error_fourier_series_for_first_tooth_passing_period(
        self: Self,
    ) -> "_1531.FourierSeries":
        """mastapy.math_utility.FourierSeries

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TransmissionErrorFourierSeriesForFirstToothPassingPeriod

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cylindrical_gear_advanced_analyses(
        self: Self,
    ) -> "List[_7342.CylindricalGearAdvancedSystemDeflection]":
        """List[mastapy.system_model.analyses_and_results.advanced_system_deflections.CylindricalGearAdvancedSystemDeflection]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CylindricalGearAdvancedAnalyses

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cylindrical_gear_mesh_system_deflection_results(
        self: Self,
    ) -> "List[_2761.CylindricalGearMeshSystemDeflectionTimestep]":
        """List[mastapy.system_model.analyses_and_results.system_deflections.CylindricalGearMeshSystemDeflectionTimestep]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CylindricalGearMeshSystemDeflectionResults

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def gear_designs(self: Self) -> "List[_1022.CylindricalGearDesign]":
        """List[mastapy.gears.gear_designs.cylindrical.CylindricalGearDesign]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearDesigns

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def max_pressure_contact_chart_for_each_tooth_pass_for_gear_a(
        self: Self,
    ) -> "List[_7331.ContactChartPerToothPass]":
        """List[mastapy.system_model.analyses_and_results.advanced_system_deflections.ContactChartPerToothPass]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaxPressureContactChartForEachToothPassForGearA

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def planetaries(self: Self) -> "List[CylindricalGearMeshAdvancedSystemDeflection]":
        """List[mastapy.system_model.analyses_and_results.advanced_system_deflections.CylindricalGearMeshAdvancedSystemDeflection]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Planetaries

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    def animation_of_max_pressure_contact_chart_for_each_tooth_pass_for_gear_a(
        self: Self,
    ):
        """Method does not return."""
        self.wrapped.AnimationOfMaxPressureContactChartForEachToothPassForGearA()

    @property
    def cast_to(
        self: Self,
    ) -> "CylindricalGearMeshAdvancedSystemDeflection._Cast_CylindricalGearMeshAdvancedSystemDeflection":
        return self._Cast_CylindricalGearMeshAdvancedSystemDeflection(self)



"""ShaftPerModeResult"""
from __future__ import annotations

from typing import TypeVar

from mastapy.system_model.analyses_and_results.modal_analyses.reporting import _4739
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_SHAFT_PER_MODE_RESULT = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses.Reporting",
    "ShaftPerModeResult",
)


__docformat__ = "restructuredtext en"
__all__ = ("ShaftPerModeResult",)


Self = TypeVar("Self", bound="ShaftPerModeResult")


class ShaftPerModeResult(_4739.ComponentPerModeResult):
    """ShaftPerModeResult

    This is a mastapy class.
    """

    TYPE = _SHAFT_PER_MODE_RESULT
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_ShaftPerModeResult")

    class _Cast_ShaftPerModeResult:
        """Special nested class for casting ShaftPerModeResult to subclasses."""

        def __init__(
            self: "ShaftPerModeResult._Cast_ShaftPerModeResult",
            parent: "ShaftPerModeResult",
        ):
            self._parent = parent

        @property
        def component_per_mode_result(
            self: "ShaftPerModeResult._Cast_ShaftPerModeResult",
        ) -> "_4739.ComponentPerModeResult":
            return self._parent._cast(_4739.ComponentPerModeResult)

        @property
        def shaft_per_mode_result(
            self: "ShaftPerModeResult._Cast_ShaftPerModeResult",
        ) -> "ShaftPerModeResult":
            return self._parent

        def __getattr__(self: "ShaftPerModeResult._Cast_ShaftPerModeResult", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "ShaftPerModeResult.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def torsional_mode_shape(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TorsionalModeShape

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: Self) -> "ShaftPerModeResult._Cast_ShaftPerModeResult":
        return self._Cast_ShaftPerModeResult(self)
